# mefs_utils

Tools for working with MEFS/EFgo assessments data

## Install

`pip install wf-mefs-utils`

## Tasks
* Gather up shared functions and definitions across assessments and move to `wf-core-data-python` (or somewhere)
* Find places where functions/methods can be reused across assessment with the addition of some arguments/switches
* Fix up README on PyPI by declaring long description to be markdown
* Move more of the data manipulation out of the individual extraction functions and into a shared function (e.g., the fetch function)
